import os
import ctypes
from mlx90640 import *


def load_driver():
    dev = MLX90640()

    cfp = os.path.dirname(os.path.realpath(__file__))
    machine = 'windows'
    shared_lib_file = 'mlx90640_driver_devicetree.dll'
    if os.environ.get('OS','') != 'Windows_NT':
        import platform
        machine = platform.machine()
        shared_lib_file = 'libmlx90640_driver_devicetree.so'

    lib = ctypes.CDLL(os.path.join(cfp, 'libs', machine, shared_lib_file), mode=ctypes.RTLD_GLOBAL)

    # struct MLX90640DriverRegister_t *MLX90640_get_register_devicetree(void);
    _get_register_devicetree = lib.MLX90640_get_register_devicetree
    _get_register_devicetree.restype = ctypes.POINTER(ctypes.c_uint16)
    _get_register_devicetree.argtypes = []
    dev._register_driver(_get_register_devicetree())






from setuptools import setup
import codecs
import os.path


def read(rel_path):
    here = os.path.abspath(os.path.dirname(__file__))
    with codecs.open(os.path.join(here, rel_path), 'r') as fp:
        return fp.read()


def get_version(rel_path):
    for line in read(rel_path).splitlines():
        if line.startswith('__version__'):
            delim = '"' if '"' in line else "'"
            return line.split(delim)[1]
    else:
        raise RuntimeError("Unable to find version string.")


# Metadata goes in setup.cfg. These are here for GitHub's dependency graph.
setup(
    name="mlx90640-driver-devicetree",
    version=get_version('devicetree/__init__.py'),
    install_requires=[
        'mlx90640-driver>=1.1.2'
    ]
)
